@@ -31,12 +31,12 @@ public:
     virtual int fetchEntityCount(const QString &appName, int processedType) const override;
     virtual NotifyEntity fetchLastEntity(const QString &appName, int processedType) override;
     virtual NotifyEntity fetchLastEntity(uint notifyId) override;
-    virtual QList<NotifyEntity> fetchExpiredEntities(qint64 expiredTime) override;
     virtual QList<NotifyEntity> fetchEntities(const QString &appName, int processedType, int maxCount) override;
     virtual QList<QString> fetchApps(int maxCount) const override;
 
     virtual void removeEntity(qint64 id) override;
     virtual void removeEntityByApp(const QString &appName) override;
+    virtual void removeEntitiesByExpiredTime(qint64 expiredTime) override;
     virtual void clear() override;
 
 private:
